---
feature_story: FS_32_05_46_00
feature_title: `arg_value` filter - `startswith` vs `contains`
feature_status: TEST
---

There are options how to include values for suggestion:
* filter `startswith`
* `in` (AKA `contains` in other langs)

However, Bash auto-completion color-highlights according to `startswith` only.
Therefore, `startswith` is selected for implementation to avoid confusion.
